// Persistence of Vision Ray Tracer Scene Description File
// File: roll_test.pov
// Vers: 3.6.1
// Desc: Scene to test the Rolling-Include 
// Date: 15.08.05 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak
// Last Update: 21.08.05 (dd.mm.yy)

//Required Files
// rolling.inc - The Rolling-Macros

//Description
// A heightfield to roll a ball on.


/*Commandline
+am2 +a0.3 +r1 +kfi1 +kff150
*/

//Homepage:
// www.nolights.de
//Email:
// LOWERCASEONLYtimISNTnikias[AT]gmx.netWARE

#include "rolling.inc"

global_settings{
  assumed_gamma 1
  ambient_light 0
}

camera{
  location <0,14,-18>
  look_at <0,0,0>
}

fog{distance 250 color <.3,.5,.9>}

light_source{
  <100,140,-100> rgb 1
  area_light x*40,y*40,25,25 orient circular adaptive 2
}

light_source{
  <-100,20,300> rgb <.1,.1,.2>
  shadowless
}
light_source{
  <10,200,30> rgb <.1,.15,.2>
  shadowless
}

//Heightfield
#declare HF_Map =
  pigment{
    bozo color_map{[0 rgb .3][.7 rgb 1][1 rgb 1]}
    turbulence .7 omega .3 octaves 8 lambda 2.5
    poly_wave 2
    scale .1
    }
#declare HF_Function = function{ pigment{HF_Map}}

#declare Mountain_Range = 
 height_field{
  function 400,400{HF_Function(x,y,z).x}
  translate <-.5,0,-.5>
  scale <40,4,40>
  }
object{Mountain_Range pigment{rgb 1}}

#declare Position = vrotate(<7,10,0>,y*360*clock);
#declare Surface_Normal = <0,0,0>;
#declare Projected_Position = trace(Mountain_Range,Position,-y,Surface_Normal)+y;

#declare Position_2 = 5*x*sin(radians(360*(clock-clock_delta))+y*10-z*9;
#declare Surface_Normal_2 = <0,0,0>;
#declare Projected_Position_2 = trace(Mountain_Range,Position_2,-y,Surface_Normal_2)+y*.75;

#if (frame_number = 1)
  Create_RollFile("test.txt",1)
  Move_RollFile("test.txt",Projected_Position)
  Randomize_RollFile("test.txt",2)

  Create_RollFile("test2.txt",.75)
  Move_RollFile("test2.txt",Projected_Position_2)
  Randomize_RollFile("test2.txt",2)
#end

Roll2Position("test.txt",Projected_Position,Surface_Normal)
Roll2Position("test2.txt",Projected_Position_2,Surface_Normal_2)

sphere{0,1
  pigment{checker color rgb 0 color rgb 1 scale .5}
  normal{bozo .1 scale .12}
  finish{
    specular .8 roughness .01
  }
  RollFile2Transform("test.txt")
}

sphere{0,.75
  pigment{spiral1 4 rotate x*0 color_map{[0 rgb y+z][.5 rgb 0][1 rgb x+y]}}
  normal{spiral1 4,.2 rotate x*90}
  finish{
    specular .8 roughness .01
  }
  RollFile2Transform("test2.txt")
}
